# REEXPORT FROM ARKHE

#' @importFrom arkhe remove_NA
#' @export
arkhe::remove_NA

#' @importFrom arkhe remove_zero
#' @export
arkhe::remove_zero

# REEXPORT FROM KHROMA

#' @importFrom khroma color
#' @export
khroma::color

#' @importFrom khroma palette_color_continuous
#' @export
khroma::palette_color_continuous

#' @importFrom khroma palette_color_discrete
#' @export
khroma::palette_color_discrete

#' @importFrom khroma palette_color_picker
#' @export
khroma::palette_color_picker

#' @importFrom khroma palette_shape
#' @export
khroma::palette_shape

#' @importFrom khroma palette_line
#' @export
khroma::palette_line

#' @importFrom khroma palette_size_sequential
#' @export
khroma::palette_size_sequential

#' @importFrom khroma palette_size_diverging
#' @export
khroma::palette_size_diverging
